
.. If you created a package, create one automodule per module in the package.

.. If your library file(s) are nested in a directory (e.g. /adafruit_foo/foo.py)
.. use this format as the module name: "adafruit_foo.foo"

.. automodule:: adafruit_tinylora
   :members:
   :member-order: bysource


.. automodule:: adafruit_tinylora.adafruit_tinylora
   :members:

.. automodule:: adafruit_tinylora.adafruit_tinylora_encryption
   :members:

.. automodule:: adafruit_tinylora.ttn_as
   :members:

.. automodule:: adafruit_tinylora.ttn_au
   :members:

.. automodule:: adafruit_tinylora.ttn_cn
   :members:

.. automodule:: adafruit_tinylora.ttn_eu
   :members:

.. automodule:: adafruit_tinylora.ttn_usa
   :members:
